添加一个tool。作用是导出账号下全部的测量数值csv文件

接口是 baseurl + cad/case/measurement/export，入参数是一个StudyInstanceUID数组，请求类型POST

{studyInstanceUids: string[]}

返回值如下

{
code: 1,
data: {route: "/cad/case/measurement/export", params: "uuid=622d05c8bd1e432cb8831c60f6043a43"},
params: "uuid=622d05c8bd1e432cb8831c60f6043a43",
route: "/cad/case/measurement/export",
msg: "操作成功",
success: true
}

获取到 `route`和`params`，就可以有完整的下载csv的url， `${base_url}/${data.route}/${data.params}`，例如: ${base_url}/cad/case/measurement/export?uuid=622d05c8bd1e432cb8831c60f6043a43

